# Scout SDK Package

Helper python package to interact with the Scout platform.

## Installation

```bash
pip install scoutsdk
```

## Usage

```python
from scoutsdk import ScoutAPI

scout = ScoutAPI(base_url="your_scout_base_url", api_access_token="you_api_access_token")
```
